FilterGraph

Struct FilterGraph 

pub struct FilterGraph {
    pub primitives: SmallVec<[FilterPrimitive; 1]>,
    pub output: FilterId,
    next_id: u16,
    filter_expansion: Rect,
    source_expansion: Rect,
}
A directed acyclic graph (DAG) of filter operations.

The graph represents a pipeline of filter primitives where outputs of some primitives can be used as inputs to others. Each primitive has a unique FilterId.

Fields

primitives: SmallVec<[FilterPrimitive; 1]>

All filter primitives in the graph, stored in insertion order.

output: FilterId

The final output filter ID whose result is the output of this graph.

next_id: u16

Next available filter ID (monotonically increasing counter).

filter_expansion: Rect

Accumulated filter expansion from all primitives in the graph, cached in user space.

source_expansion: Rect

Accumulated source expansion from all primitives in the graph, cached in user space.

Implementations

Source

impl FilterGraph

pub fn new() -> Self

Create a new empty filter graph.

pub fn add( &mut self, primitive: FilterPrimitive, _inputs: Option<FilterInputs>, ) -> FilterId

Add a filter primitive with optional inputs.

Returns a FilterId that can be referenced by other primitives. Automatically updates the accumulated source and filter expansion requirements.

pub fn set_output(&mut self, output: FilterId)

Set the output filter for the graph.

pub fn filter_expansion(&self, transform: &Affine) -> Rect

The filter expansion of all filters in the graph, see Filter::filter_expansion.

pub fn source_expansion(&self, transform: &Affine) -> Rect

The source expansion of all filters in the graph, see Filter::source_expansion.