FilterInputs

Struct FilterInputs 

pub struct FilterInputs {
    pub primary: FilterInput,
    pub secondary: Option<FilterInput>,
}
Input connections for a filter primitive.

Fields

primary: FilterInput

Primary input (“in” attribute in SVG).

secondary: Option<FilterInput>

Secondary input (“in2” attribute in SVG, for composite/blend operations).

Implementations

Source

impl FilterInputs

pub fn single(input: FilterInput) -> Self

Create filter inputs with a single input.

Use this for primitives that operate on a single source (blur, color matrix, etc.).

pub fn dual(input1: FilterInput, input2: FilterInput) -> Self

Create filter inputs with two inputs (for composite, blend, etc.).

Use this for primitives that combine two sources (composite, blend, displacement map, etc.).